January 2025  

Future of Jobs Report 2025  

1  

# Drivers of labour-market transformation

Technological developments, the green transition, macroeconomic and geoeconomic shifts, and demographic changes are driving transformation in the global labour market, reshaping both jobs and required skills. This chapter provides a picture of how companies expect these macrotrends to drive industry transformation by 2030.

## 1.1 Expected impact of macrotrends on business transformation

**FIGURE 1.1**

**Macrotrends driving business transformation**  
Share of employers surveyed that identify the stated trend as likely to drive business transformation.

| Macrotrend | Share of employers surveyed (%) |
| --- | --- |
| Broadening digital access | 60% |
| Rising cost of living, higher prices or inflation | 50% |
| Increased efforts and investments to reduce carbon emissions | 47% |
| Increased focus on labour and social issues | 46% |
| Slower economic growth | 42% |
| Increased efforts and investments to adapt to climate change | 41% |
| Ageing and declining working-age populations | 40% |
| Increased geopolitical division and conflicts | 34% |
| Growing working-age populations | 24% |
| Increased restrictions to global trade and investment | 23% |
| Increased government subsidies and industrial policy | 21% |
| Stricter anti-trust and competition regulations | 17% |

Share of employers surveyed (%)

Demographic shifts  
Economic uncertainty  
Geoeconomic fragmentation  
Green transition  
Societal issues  
Technology change  

Source  
World Economic Forum, Future of Jobs Survey 2024.

---

## Technological change

More employers – 60% – expect broadening digital access to transform their business than any other trend, with similar proportions of employers across all regions selecting this trend. This growing digital access is a critical enabler for new technologies to transform labour markets (Figure 1.1).

The Future of Jobs Survey asked employers how advances in nine key technologies are transforming  

Future of Jobs Report 2025  10